# Generated by Django 4.2.9 on 2024-02-07 17:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('payroll', '0013_payrollmutation'),
        ('payroll', '0014_alter_benefitattachment_date_created_and_more'),
    ]

    operations = [
    ]
