# Generated by Django 3.2.24 on 2024-02-21 23:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payroll', '0018_auto_20240212_1355'),
    ]

    operations = [
        migrations.AddField(
            model_name='csvreconciliationupload',
            name='file_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name='historicalcsvreconciliationupload',
            name='file_name',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
