# Generated by Django 4.2.9 on 2024-02-07 16:33

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('payroll', '0010_alter_paymentpoint_ppm'),
        ('payroll', '0012_auto_20240202_1619'),
    ]

    operations = [
    ]
