# Generated by Django 3.2.19 on 2024-02-02 16:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payroll', '0011_auto_20240202_1140'),
    ]

    operations = [
        migrations.AlterField(
            model_name='benefitconsumption',
            name='status',
            field=models.CharField(choices=[('ACCEPTED', 'ACCEPTED'), ('CREATED', 'CREATED'), ('APPROVE_FOR_PAYMENT', 'APPROVE_FOR_PAYMENT'), ('REJECTED', 'REJECTED'), ('DUPLICATE', 'DUPLICATE'), ('RECONCILED', 'RECONCILED')], default='ACCEPTED', max_length=100),
        ),
        migrations.AlterField(
            model_name='historicalbenefitconsumption',
            name='status',
            field=models.CharField(choices=[('ACCEPTED', 'ACCEPTED'), ('CREATED', 'CREATED'), ('APPROVE_FOR_PAYMENT', 'APPROVE_FOR_PAYMENT'), ('REJECTED', 'REJECTED'), ('DUPLICATE', 'DUPLICATE'), ('RECONCILED', 'RECONCILED')], default='ACCEPTED', max_length=100),
        ),
        migrations.AlterField(
            model_name='historicalpayroll',
            name='status',
            field=models.CharField(choices=[('PENDING_APPROVAL', 'PENDING_APPROVAL'), ('APPROVE_FOR_PAYMENT', 'APPROVE_FOR_PAYMENT'), ('REJECTED', 'REJECTED'), ('RECONCILED', 'RECONCILED')], default='PENDING_APPROVAL', max_length=100),
        ),
        migrations.AlterField(
            model_name='payroll',
            name='status',
            field=models.CharField(choices=[('PENDING_APPROVAL', 'PENDING_APPROVAL'), ('APPROVE_FOR_PAYMENT', 'APPROVE_FOR_PAYMENT'), ('REJECTED', 'REJECTED'), ('RECONCILED', 'RECONCILED')], default='PENDING_APPROVAL', max_length=100),
        ),
    ]
