# Generated by Django 3.2.24 on 2024-02-27 09:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('payroll', '0019_auto_20240221_2330'),
    ]

    operations = [
        migrations.AlterField(
            model_name='csvreconciliationupload',
            name='status',
            field=models.CharField(choices=[('TRIGGERED', 'Triggered'), ('IN_PROGRESS', 'In progress'), ('SUCCESS', 'Success'), ('PARTIAL_SUCCESS', 'Partial Success'), ('WAITING_FOR_VERIFICATION', 'WAITING_FOR_VERIFICATION'), ('FAIL', 'Fail')], default='TRIGGERED', max_length=255),
        ),
        migrations.AlterField(
            model_name='historicalcsvreconciliationupload',
            name='status',
            field=models.CharField(choices=[('TRIGGERED', 'Triggered'), ('IN_PROGRESS', 'In progress'), ('SUCCESS', 'Success'), ('PARTIAL_SUCCESS', 'Partial Success'), ('WAITING_FOR_VERIFICATION', 'WAITING_FOR_VERIFICATION'), ('FAIL', 'Fail')], default='TRIGGERED', max_length=255),
        ),
    ]
